==> ejc-front-impl-3.0.1-20230710.061131-158-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeEnvironment.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

public class IdeEnvironment implements Serializable {
	private static final long serialVersionUID = -5808530840956022593L;

	private Long id;

	private String name; // 环境名称

	private String url; // 环境url(唯一性)

	private Integer enableWhiteList; // 是否存在白名单

	private Date createDate;

	private Long createId;

	private Integer isDelete;

	private Date modifyDate;

	private Long modifyId;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public Integer getEnableWhiteList() {
		return enableWhiteList;
	}

	public void setEnableWhiteList(Integer enableWhiteList) {
		this.enableWhiteList = enableWhiteList;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

}

==> ejc-front-impl-3.0.1-20250516.080027-190-sources.jar: com/ejianc/foundation/front/business/ide/entity/IdeEnvironment.java <==
package com.ejianc.foundation.front.business.ide.entity;

import java.io.Serializable;
import java.util.Date;

public class IdeEnvironment implements Serializable {
	private static final long serialVersionUID = -5808530840956022593L;

	private Long id;

	private String name; // 环境名称

	private String url; // 环境url(唯一性)

	private String publishUser; // 可以发布的用户id集合

	private Integer enableWhiteList; // 是否存在白名单

	private Date createDate;

	private Long createId;

	private Integer isDelete;

	private Date modifyDate;

	private Long modifyId;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getPublishUser() {
		return publishUser;
	}

	public void setPublishUser(String publishUser) {
		this.publishUser = publishUser;
	}

	public Integer getEnableWhiteList() {
		return enableWhiteList;
	}

	public void setEnableWhiteList(Integer enableWhiteList) {
		this.enableWhiteList = enableWhiteList;
	}

	public Date getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	public Long getCreateId() {
		return createId;
	}

	public void setCreateId(Long createId) {
		this.createId = createId;
	}

	public Integer getIsDelete() {
		return isDelete;
	}

	public void setIsDelete(Integer isDelete) {
		this.isDelete = isDelete;
	}

	public Date getModifyDate() {
		return modifyDate;
	}

	public void setModifyDate(Date modifyDate) {
		this.modifyDate = modifyDate;
	}

	public Long getModifyId() {
		return modifyId;
	}

	public void setModifyId(Long modifyId) {
		this.modifyId = modifyId;
	}

}
